From 4742ee549dd0a1bf6fbb7c02db750b72780cb640 Mon Sep 17 00:00:00 2001
From: Alyssa Rosenzweig <alyssa@collabora.com>
Date: Tue, 21 Dec 2021 16:19:15 -0500
Subject: [PATCH] panfrost: Add Mali-G76 support

Identical hardware to Mali-G52, different GPU ID to allowlist.

Signed-off-by: Alyssa Rosenzweig <alyssa@collabora.com>
---
 src/gallium/drivers/panfrost/pan_screen.c | 1 +
 src/panfrost/include/panfrost-quirks.h    | 1 +
 src/panfrost/lib/pan_props.c              | 1 +
 src/panfrost/perf/pan_perf.c              | 2 ++
 4 files changed, 5 insertions(+)

diff --git a/src/gallium/drivers/panfrost/pan_screen.c b/src/gallium/drivers/panfrost/pan_screen.c
index 4a391adc8c4..061c3dce7f2 100644
--- a/src/gallium/drivers/panfrost/pan_screen.c
+++ b/src/gallium/drivers/panfrost/pan_screen.c
@@ -861,6 +861,7 @@ panfrost_create_screen(int fd, struct renderonly *ro)
         case 0x820: /* T820 */
         case 0x860: /* T860 */
         case 0x6221: /* G72 */
+        case 0x7001: /* G76 */
         case 0x7093: /* G31 */
         case 0x7212: /* G52 */
         case 0x7402: /* G52r1 */
diff --git a/src/panfrost/include/panfrost-quirks.h b/src/panfrost/include/panfrost-quirks.h
index 804dc311c29..c2121736050 100644
--- a/src/panfrost/include/panfrost-quirks.h
+++ b/src/panfrost/include/panfrost-quirks.h
@@ -110,6 +110,7 @@ panfrost_get_quirks(unsigned gpu_id, unsigned gpu_revision)
                 return BIFROST_QUIRKS | HAS_SWIZZLES
                         | (gpu_revision >= 0x30 ? HAS_ANISOTROPIC : 0);
 
+        case 0x7001: /* G76 */
         case 0x7093: /* G31 */
         case 0x7212: /* G52 */
         case 0x7402: /* G52r1 */
diff --git a/src/panfrost/lib/pan_props.c b/src/panfrost/lib/pan_props.c
index 44d626fd6ff..7735c334ac6 100644
--- a/src/panfrost/lib/pan_props.c
+++ b/src/panfrost/lib/pan_props.c
@@ -206,6 +206,7 @@ panfrost_model_name(unsigned gpu_id)
         case 0x860: return "Mali-T860 (Panfrost)";
         case 0x880: return "Mali-T880 (Panfrost)";
         case 0x6221: return "Mali-G72 (Panfrost)";
+        case 0x7001: return "Mali-G76 (Panfrost)";
         case 0x7093: return "Mali-G31 (Panfrost)";
         case 0x7212: return "Mali-G52 (Panfrost)";
         case 0x7402: return "Mali-G52 r1 (Panfrost)";
diff --git a/src/panfrost/perf/pan_perf.c b/src/panfrost/perf/pan_perf.c
index f20a81b2238..90fd2a6d4a5 100644
--- a/src/panfrost/perf/pan_perf.c
+++ b/src/panfrost/perf/pan_perf.c
@@ -65,6 +65,8 @@ get_perf_config(unsigned int gpu_id)
       return &panfrost_perf_config_t88x;
    case 0x6221:
       return &panfrost_perf_config_thex;
+   case 0x7001:
+      return &panfrost_perf_config_tnox;
    case 0x7093:
       return &panfrost_perf_config_tdvx;
    case 0x7212:
-- 
2.30.2

